"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var os_1 = require("os");
var fs_1 = require("fs");
var path_1 = require("path");
var consola = require('consola');
var readPkgUp = require('read-pkg-up');
var config_1 = require("./config");
var ConfigProvider = /** @class */ (function () {
    function ConfigProvider(rootPath) {
        this.rootPath = rootPath;
        this.packageJsonObj = readPkgUp.sync({
            cwd: this.rootPath
        }).pkg;
    }
    ConfigProvider.prototype.getConfig = function () {
        try {
            if (this.packageJsonHasConfig()) {
                var majesticCofig = this.packageJsonObj.majestic;
                var config = config_1.default.packageJsonConfig(this.rootPath, majesticCofig);
                return config;
            }
            else if (this.isBootstrappedWithCreateReactApp(this.rootPath)) {
                return config_1.default.craConfigProvider(this.rootPath);
            }
            else if (this.usesJestCli()) {
                return config_1.default.jestCliConfigProvider(this.rootPath);
            }
            return config_1.default.defaultConfigProvider(this.rootPath);
        }
        catch (e) {
            consola.error('This directory does not seems to use Jest. Please open an issue if you think this is a bug.');
            throw e;
        }
    };
    ConfigProvider.prototype.packageJsonHasConfig = function () {
        return Boolean(this.packageJsonObj && this.packageJsonObj.majestic);
    };
    ConfigProvider.prototype.usesJestCli = function () {
        if (!this.packageJsonObj) {
            return false;
        }
        return Boolean((this.packageJsonObj.dependencies &&
            this.packageJsonObj.dependencies['jest-cli']) ||
            (this.packageJsonObj.devDependencies &&
                this.packageJsonObj.devDependencies['jest-cli']));
    };
    ConfigProvider.prototype.isBootstrappedWithCreateReactApp = function (rootPath) {
        return (this.hasExecutable(rootPath, 'node_modules/.bin/react-scripts') ||
            this.hasExecutable(rootPath, 'node_modules/react-scripts/node_modules/.bin/jest') ||
            this.hasExecutable(rootPath, 'node_modules/react-native-scripts'));
    };
    ConfigProvider.prototype.hasExecutable = function (rootPath, executablePath) {
        var ext = os_1.platform() === 'win32' ? '.cmd' : '';
        var absolutePath = path_1.join(rootPath, executablePath + ext);
        return fs_1.existsSync(absolutePath);
    };
    return ConfigProvider;
}());
exports.ConfigProvider = ConfigProvider;
//# sourceMappingURL=configProvider.js.map