"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var micromatch = require('micromatch');
var pathUtil = require("path");
var escapePathForRegex = require('jest-regex-util').escapePathForRegex;
var globsToMatcher = function (globs) {
    if (globs == null || globs.length === 0) {
        return function () { return true; };
    }
    var matchers = globs.map(function (each) { return micromatch.matcher(each, { dot: true }); });
    return function (path) {
        return matchers.some(function (each) { return each(path); });
    };
};
var regexToMatcher = function (testRegex) {
    if (!testRegex) {
        return function () { return true; };
    }
    var regex = new RegExp(testRegex);
    return function (path) { return regex.test(path); };
};
var TestFileSearcher = /** @class */ (function () {
    function TestFileSearcher(config) {
        var _this = this;
        this._rootPattern = new RegExp((config.jest.roots || [])
            .map(function (dir) { return escapePathForRegex(dir + pathUtil.sep); })
            .join('|'));
        var ignorePattern = config.jest.testPathIgnorePatterns || [];
        this._testIgnorePattern = ignorePattern.length
            ? new RegExp(ignorePattern.join('|'))
            : undefined;
        this._testPathCases = {
            roots: function (path) { return _this._rootPattern.test(path); },
            testMatch: globsToMatcher(config.jest.testMatch),
            testPathIgnorePatterns: function (path) {
                return !_this._testIgnorePattern || !_this._testIgnorePattern.test(path);
            },
            testRegex: regexToMatcher(config.jest.testRegex || '')
        };
    }
    TestFileSearcher.prototype.isTestFilePath = function (path) {
        var _this = this;
        return Object.keys(this._testPathCases).every(function (key) {
            return _this._testPathCases[key](path);
        });
    };
    return TestFileSearcher;
}());
function getTestPatternsMatcher(root, config) {
    var fileSearcher = new TestFileSearcher(config);
    return function (path) { return fileSearcher.isTestFilePath(path); };
}
exports.getTestPatternsMatcher = getTestPatternsMatcher;
//# sourceMappingURL=fileMatcher.js.map