var WebSocket = require('ws');
var connectionPromise = new Promise(function (resolve) {
    var connection = new WebSocket('ws://localhost:' + process.env.serverPort);
    connection.on('open', function open() {
        resolve(connection);
        console.log('connection is open from repoter');
    });
});
var MyCustomReporter = /** @class */ (function () {
    function MyCustomReporter(globalConfig, options) {
        this._globalConfig = globalConfig;
        this._options = options;
        this.testStartQueue = [];
        this.testResultQueue = [];
        this.onRunStartQueue = [];
    }
    MyCustomReporter.prototype.onTestStart = function (test) {
        connectionPromise.then(function (connection) {
            connection.send(JSON.stringify({
                source: 'jest-test-reporter',
                event: 'onTestStart',
                payload: {
                    test: test
                }
            }));
        });
    };
    MyCustomReporter.prototype.onTestResult = function (test, testResult, aggregatedResult) {
        var _this = this;
        this.testResultQueue.unshift({
            test: test,
            testResult: testResult,
            aggregatedResult: aggregatedResult
        });
        connectionPromise.then(function (connection) {
            connection.send(JSON.stringify({
                source: 'jest-test-reporter',
                event: 'onTestResult',
                payload: _this.testResultQueue
            }));
            _this.testResultQueue = [];
        });
    };
    MyCustomReporter.prototype.onRunStart = function (results) {
        connectionPromise.then(function (connection) {
            connection.send(JSON.stringify({
                source: 'jest-test-reporter',
                event: 'onRunStart',
                payload: {
                    results: results
                }
            }));
        });
    };
    MyCustomReporter.prototype.onRunComplete = function (contexts, results) {
        connectionPromise.then(function (connection) {
            connection.send(JSON.stringify({
                source: 'jest-test-reporter',
                event: 'onRunComplete',
                payload: {
                    results: results,
                    contexts: contexts
                }
            }));
        });
    };
    return MyCustomReporter;
}());
module.exports = MyCustomReporter;
//# sourceMappingURL=reporter.js.map