"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
Object.defineProperty(exports, "__esModule", { value: true });
var mobx_1 = require("mobx");
var It_1 = require("./It");
var CoverageSummary_1 = require("./CoverageSummary");
var statusLabel_1 = require("../components/statusLabel");
var Node = /** @class */ (function () {
    function Node(path, type, label, itBlocks) {
        this.isExpanded = true;
        this.isSelected = false;
        this.secondaryLabel = '';
        this.itBlocks = mobx_1.observable([]);
        this.coverage = new CoverageSummary_1.default();
        this.executionTime = 0;
        this.status = 'pending';
        this.path = path;
        this.type = type;
        this.label = label;
        this.children = [];
        for (var _i = 0, itBlocks_1 = itBlocks; _i < itBlocks_1.length; _i++) {
            var _a = itBlocks_1[_i], name_1 = _a.name, line = _a.start.line;
            this.itBlocks.push(new It_1.default(name_1, line));
        }
        if (type === 'directory') {
            this.icon = 'folder-open';
        }
        else {
            this.icon = 'document';
        }
    }
    Node.convertToNode = function (_a, flatNodeMap, parent) {
        var path = _a.path, type = _a.type, label = _a.label, children = _a.children, itBlocks = _a.itBlocks;
        if (flatNodeMap === void 0) { flatNodeMap = new Map(); }
        var node = new Node(path, type, label, itBlocks || []);
        node.isExpanded = false;
        node.parent = parent;
        node.isExpanded = true;
        flatNodeMap.set(path.toLowerCase(), node);
        if (!children) {
            return {
                node: node,
                flatNodeMap: flatNodeMap
            };
        }
        node.children = children.map(function (child) { return Node.convertToNode(child, flatNodeMap, node).node; });
        return {
            node: node,
            flatNodeMap: flatNodeMap
        };
    };
    Node.prototype.toggleSelection = function (selection) {
        if (selection === void 0) { selection = true; }
        this.isSelected = selection;
        var current = this;
        while (current) {
            current.isExpanded = true;
            current = current.parent;
        }
    };
    Node.prototype.getItBlockByTitle = function (title) {
        return this.itBlocks.find(function (it) { return it.name === title; });
    };
    Node.prototype.executeAllItBlocks = function () {
        for (var _i = 0, _a = this.itBlocks; _i < _a.length; _i++) {
            var it_1 = _a[_i];
            it_1.startExecting();
        }
    };
    Node.prototype.execute = function () {
        this.resetStatus();
        this.executeAllItBlocks();
    };
    Object.defineProperty(Node.prototype, "totalTests", {
        get: function () {
            return this.itBlocks.length;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Node.prototype, "totalPassedTests", {
        get: function () {
            return this.itBlocks.filter(function (e) { return e.status === 'passed'; }).length;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Node.prototype, "totalFailedTests", {
        get: function () {
            return this.itBlocks.filter(function (e) { return e.status === 'failed'; }).length;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Node.prototype, "totalSkippedTests", {
        get: function () {
            return this.itBlocks.filter(function (e) { return e.status === 'skipped'; }).length;
        },
        enumerable: true,
        configurable: true
    });
    Node.prototype.setItBlocks = function (itBlocks) {
        this.itBlocks.clear();
        for (var _i = 0, itBlocks_2 = itBlocks; _i < itBlocks_2.length; _i++) {
            var _a = itBlocks_2[_i], name_2 = _a.name, line = _a.start.line;
            this.itBlocks.push(new It_1.default(name_2, line));
        }
    };
    Node.prototype.resetStatus = function () {
        this.itBlocks.map(function (it) { return it.resetStatus(); });
        this.setStatus();
    };
    Node.prototype.setStatus = function () {
        var isFailed = this.itBlocks.some(function (it) { return it.status === 'failed'; });
        var allPending = this.itBlocks.every(function (it) { return it.status === 'pending'; });
        var allPassed = this.itBlocks.every(function (it) { return it.status === 'passed' || it.status === 'pending'; });
        if (isFailed) {
            this.status = 'failed';
        }
        else if (allPassed && !allPending) {
            this.status = 'passed';
        }
        else {
            this.status = 'pending';
        }
        this.secondaryLabel = this.type === 'file' ? statusLabel_1.getLabel(this.status) : '';
    };
    __decorate([
        mobx_1.observable
    ], Node.prototype, "children", void 0);
    __decorate([
        mobx_1.observable
    ], Node.prototype, "hasCaret", void 0);
    __decorate([
        mobx_1.observable
    ], Node.prototype, "icon", void 0);
    __decorate([
        mobx_1.observable
    ], Node.prototype, "id", void 0);
    __decorate([
        mobx_1.observable
    ], Node.prototype, "isExpanded", void 0);
    __decorate([
        mobx_1.observable
    ], Node.prototype, "isSelected", void 0);
    __decorate([
        mobx_1.observable
    ], Node.prototype, "label", void 0);
    __decorate([
        mobx_1.observable
    ], Node.prototype, "secondaryLabel", void 0);
    __decorate([
        mobx_1.observable
    ], Node.prototype, "className", void 0);
    __decorate([
        mobx_1.observable
    ], Node.prototype, "path", void 0);
    __decorate([
        mobx_1.observable
    ], Node.prototype, "output", void 0);
    __decorate([
        mobx_1.observable
    ], Node.prototype, "itBlocks", void 0);
    __decorate([
        mobx_1.observable
    ], Node.prototype, "type", void 0);
    __decorate([
        mobx_1.observable
    ], Node.prototype, "content", void 0);
    __decorate([
        mobx_1.observable
    ], Node.prototype, "coverage", void 0);
    __decorate([
        mobx_1.observable
    ], Node.prototype, "executionTime", void 0);
    __decorate([
        mobx_1.observable
    ], Node.prototype, "status", void 0);
    __decorate([
        mobx_1.computed
    ], Node.prototype, "totalTests", null);
    __decorate([
        mobx_1.computed
    ], Node.prototype, "totalPassedTests", null);
    __decorate([
        mobx_1.computed
    ], Node.prototype, "totalFailedTests", null);
    __decorate([
        mobx_1.computed
    ], Node.prototype, "totalSkippedTests", null);
    return Node;
}());
exports.default = Node;
//# sourceMappingURL=Node.js.map