#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var express = require("express");
var http = require("http");
var cors = require('cors');
var fs = require('fs');
var path_1 = require("path");
var chalk = require('chalk');
var server_1 = require("../core/portal/server");
var engine_1 = require("../core/engine");
var remoteMethods_1 = require("./remoteMethods");
var relay_1 = require("./relay");
var configProvider_1 = require("../core/engine/configProvider");
var template_1 = require("./template");
var chromeLauncher = require('chrome-launcher');
var parseArgs = require('minimist');
var ora = require('ora');
var opn = require('opn');
var getPort = require('get-port');
var args = parseArgs(process.argv);
var initialPort = 3005;
function default_1(rootDirectory, autoLaunch) {
    if (rootDirectory === void 0) { rootDirectory = ''; }
    if (autoLaunch === void 0) { autoLaunch = true; }
    return getPort({ port: initialPort }).then(function (port) {
        process.env.serverPort = port;
        var app = express();
        if (!args.dev) {
            app.get('/', function (req, res) {
                res.type('text/html');
                var content = fs.readFileSync(path_1.join(__dirname, '../../build/index.html'), 'utf8');
                var replacedStreing = content.replace('serverPort: 3005', template_1.default(port));
                res.send(replacedStreing);
            });
        }
        app.use(cors());
        app.options('*', cors());
        app.use(express.static(path_1.join(__dirname, '../../build')));
        var server = http.createServer(app);
        var projectPath = rootDirectory || args.project || process.cwd();
        var configProvider = new configProvider_1.ConfigProvider(projectPath);
        var engine = new engine_1.default(projectPath, configProvider.getConfig(), {
            serverPort: port
        });
        var spinner = ora('Reading tests').start();
        engine.testFiles.read(engine.root);
        spinner.stop();
        relay_1.getConnection(server);
        var serverApp = server.listen(port, function (err) {
            if (err) {
                console.log(err);
            }
            engine.getVersion().then(function (version) {
                console.log(chalk.black.bgYellow.bold("Majestic v" + version) + "\n" + chalk.white('Zero config UI for Jest'));
                if (args.app) {
                    chromeLauncher
                        .launch({
                        startingUrl: "http://localhost:" + port,
                        chromeFlags: ["--app=http://localhost:" + port]
                    })
                        .then(function (chrome) {
                        console.log('Opening app');
                    });
                }
                else {
                    if (!args.dev && autoLaunch) {
                        opn("http://localhost:" + port);
                    }
                    console.log("visit " + chalk.green("http://localhost:" + port));
                }
            });
            server_1.register('ui', remoteMethods_1.default(engine), function (remote) {
                engine.watcher.handlers(function (path) {
                    remote.onFileAdd(path, engine.testFiles.read(engine.root));
                }, function (path) {
                    remote.onFileDelete(path);
                }, function (path, itBlocks) {
                    if (itBlocks) {
                        remote.onFileChange(path, itBlocks);
                    }
                });
                engine.testRunner.registerOnDebuggerExit(function () {
                    remote.onDebuggerExit();
                });
            });
        });
        process.on('exit', function () {
            console.log('Killing the runner before exit');
            engine.testRunner.kill();
        });
        return {
            port: port,
            terminate: function () {
                serverApp.close(function () {
                    console.log('Doh :(');
                });
                engine.testRunner.kill();
            }
        };
    });
}
exports.default = default_1;
//# sourceMappingURL=index.js.map