"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var latestVersion = require('latest-version');
function getRemoteMethods(engine) {
    return {
        getFiles: function () {
            return JSON.stringify(engine.testFiles.getFiles());
        },
        reFetchFiles: function () {
            return JSON.stringify(engine.testFiles.read(engine.root));
        },
        run: function (watch, disableCoverage, testFile, testName) {
            if (testFile === void 0) { testFile = ''; }
            if (testName === void 0) { testName = ''; }
            engine.testRunner.start(watch, disableCoverage, testFile, testName);
            return JSON.stringify({});
        },
        stop: function () {
            engine.testRunner.kill();
            return JSON.stringify({});
        },
        filterFileInWatch: function (fileName) {
            engine.testRunner.runTestByFileInteractive(fileName);
            return JSON.stringify({});
        },
        filterTestInWatch: function (fileName, testName) {
            engine.testRunner.runTestByTestNameInteractive(fileName, testName);
            return JSON.stringify({});
        },
        updateSnapshot: function (fileName, testName) {
            return engine.testRunner.updateSnapshot(fileName, testName);
        },
        launchInEditor: function (fileName, lineNumber) {
            engine.launchEditor(fileName, lineNumber);
            return JSON.stringify({});
        },
        startDebugging: function (fileName) {
            return engine.testRunner.startInspect(fileName);
        },
        getConfig: function () {
            return JSON.stringify({
                nodePath: engine.preference.getNodePath(),
                showTreeView: engine.preference.getTreeViewToggle(),
                isMajesticLogEnabled: engine.preference.getMajesticLogEnabled()
            });
        },
        setConfig: function (nodePath, showTreeView, isMajesticLogEnabled) {
            engine.preference.setNodePath(nodePath);
            engine.preference.setShowTreeView(showTreeView);
            engine.preference.setMajesticLogEnabled(isMajesticLogEnabled);
            return JSON.stringify({});
        },
        getVersion: function () {
            return engine.getVersion().then(function (version) {
                return JSON.stringify({
                    version: version
                });
            });
        },
        getLatestVersion: function () {
            return latestVersion('majestic').then(function (version) {
                return JSON.stringify({
                    version: version
                });
            });
        },
        getDebugInfo: function () {
            return JSON.stringify({
                rootPath: engine.root,
                jestExecuablePath: engine.testRunner.getJestExecutablePath()
            });
        }
    };
}
exports.default = getRemoteMethods;
//# sourceMappingURL=remoteMethods.js.map